==> rdc_flutter_sdk-0.0.1.tar.gz: lib/src/model/hive/rabbit_request_hive.dart <==
import 'package:hive/hive.dart';
import 'package:rdc_flutter_sdk/src/model/base_model.dart';
import 'package:rdc_flutter_sdk/src/model/rabbit_request.dart';

part 'rabbit_request_hive.g.dart';

@HiveType(typeId: 0)
class RabbitRequestHive extends HiveBaseModel<RabbitRequest> {
  @HiveField(0)
  late String memberId;
  @HiveField(1)
  late String ssoId;
  @HiveField(2)
  late String globalId;
  @HiveField(3)
  late String sdkVersion;
  @HiveField(4)
  late String sessionEvent;
  @HiveField(5)
  late String sessionId;
  @HiveField(6)
  late String touchPoint;
  @HiveField(7)
  late String eventName;
  @HiveField(8)
  late String eventValue;
  @HiveField(9)
  late String osVer;
  @HiveField(10)
  late String osType;
  @HiveField(11)
  late String display;
  @HiveField(12)
  late String localeCountry;
  @HiveField(13)
  late String localeLang;
  @HiveField(14)
  late String latitude;
  @HiveField(15)
  late String longitude;
  @HiveField(16)
  late String maid;
  @HiveField(17)
  late String device;
  @HiveField(18)
  late String model;
  @HiveField(19)
  late String brandName;
  @HiveField(20)
  late String board;
  @HiveField(21)
  late String appVer;
  @HiveField(22)
  late String appVerNum;
  @HiveField(23)
  late String prevAppVer;
  @HiveField(24)
  late String prevAppVerNum;
  @HiveField(25)
  dynamic dataLayer;
  @HiveField(26)
  late String time;
  @HiveField(27, defaultValue: false)
  late bool isSend;

  @override
  RabbitRequest mapFromHive(int id) {
    return RabbitRequest()
      ..id = id
      ..memberId = memberId
      ..ssoId = ssoId
      ..globalId = globalId
      ..sdkVersion = sdkVersion
      ..sessionEvent = sessionEvent
      ..sessionId = sessionId
      ..eventName = eventName
      ..eventValue = eventValue
      ..osVer = osVer
      ..osType = osType
      ..display = display
      ..localeCountry = localeCountry
      ..localeLang = localeLang
      ..latitude = latitude
      ..longitude = longitude
      ..maid = maid
      ..device = device
      ..model = model
      ..brandName = brandName
      ..board = board
      ..appVer = appVer
      ..appVerNum = appVerNum
      ..prevAppVer = prevAppVer
      ..prevAppVerNum = prevAppVerNum
      ..dataLayer = dataLayer
      ..time = time
      ..isSend = isSend;
  }
}

==> rdc_flutter_sdk-0.0.20-dev.tar.gz: lib/src/model/hive/rabbit_request_hive.dart <==
import 'package:hive/hive.dart';
import 'package:rdc_flutter_sdk/src/model/base_model.dart';
import 'package:rdc_flutter_sdk/src/model/rabbit_request.dart';

part 'rabbit_request_hive.g.dart';

@HiveType(typeId: 0)
class RabbitRequestHive extends HiveBaseModel<RabbitRequest> {
  @HiveField(0)
  late String memberId;
  @HiveField(1)
  late String ssoId;
  @HiveField(2)
  late String globalId;
  @HiveField(3)
  late String sdkVersion;
  @HiveField(4)
  late String sessionEvent;
  @HiveField(5)
  late String sessionId;
  @HiveField(6)
  late String touchPoint;
  @HiveField(7)
  late String eventName;
  @HiveField(8)
  late String eventValue;
  @HiveField(9)
  late String osVer;
  @HiveField(10)
  late String osType;
  @HiveField(11)
  late String display;
  @HiveField(12)
  late String localeCountry;
  @HiveField(13)
  late String localeLang;
  @HiveField(14)
  late String latitude;
  @HiveField(15)
  late String longitude;
  @HiveField(16)
  late String maid;
  @HiveField(17)
  late String device;
  @HiveField(18)
  late String model;
  @HiveField(19)
  late String brandName;
  @HiveField(20)
  late String board;
  @HiveField(21)
  late String appVer;
  @HiveField(22)
  late String appVerNum;
  @HiveField(23)
  late String prevAppVer;
  @HiveField(24)
  late String prevAppVerNum;
  @HiveField(25)
  dynamic dataLayer;
  @HiveField(26)
  late String time;
  @HiveField(27, defaultValue: false)
  late bool isSend;

  @override
  RabbitRequest mapFromHive(int id) {
    return RabbitRequest()
      ..id = id
      ..memberId = memberId
      ..ssoId = ssoId
      ..globalId = globalId
      ..sdkVersion = sdkVersion
      ..sessionEvent = sessionEvent
      ..sessionId = sessionId
      ..eventName = eventName
      ..eventValue = eventValue
      ..osVer = osVer
      ..osType = osType
      ..display = display
      ..localeCountry = localeCountry
      ..localeLang = localeLang
      ..latitude = latitude.isEmpty ? null : latitude
      ..longitude = longitude.isEmpty ? null : longitude
      ..maid = maid.isEmpty ? null : maid
      ..device = device
      ..model = model
      ..brandName = brandName
      ..board = board
      ..appVer = appVer
      ..appVerNum = appVerNum
      ..prevAppVer = prevAppVer.isEmpty ? null : prevAppVer
      ..prevAppVerNum = prevAppVerNum.isEmpty ? null : prevAppVerNum
      ..dataLayer = dataLayer
      ..time = time
      ..isSend = isSend;
  }
}
